summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLorenzo Manacorda <lorenzo.manacorda@gmail.com>2015-09-16 14:16:19 +0200
committerLorenzo Manacorda <lorenzo.manacorda@gmail.com>2015-09-16 15:07:57 +0200
commitb2297c291ea452ee19634105b75525c4223122c0 (patch)
tree388a5e1b83938c87431f2aa553617fda1ce108b8
parent128c0cd4f212511365cfd8290172f8c6871d5768 (diff)
downloadbundler-b2297c291ea452ee19634105b75525c4223122c0.tar.gz
fix remaining usages of `:system` in specs
-rw-r--r--spec/commands/exec_spec.rb8
-rw-r--r--spec/install/gems/sudo_spec.rb12
-rw-r--r--spec/other/platform_spec.rb8
3 files changed, 19 insertions, 9 deletions
diff --git a/spec/install/gems/sudo_spec.rb b/spec/install/gems/sudo_spec.rb
index 714589e004..83744caf5f 100644
--- a/spec/install/gems/sudo_spec.rb
+++ b/spec/install/gems/sudo_spec.rb
@@ -10,7 +10,8 @@ describe "when using sudo", :sudo => true do
end
it "installs" do
- install_gemfile <<-G, :system => true
+ bundler "config path.system true"
+ install_gemfile <<-G
source "file://#{gem_repo1}"
gem "rack"
G
@@ -28,7 +29,8 @@ describe "when using sudo", :sudo => true do
end
it "installs" do
- install_gemfile <<-G, :system => true
+ bundler "config path.system true"
+ install_gemfile <<-G
source "file://#{gem_repo1}"
gem "rack", '1.0'
gem "thin"
@@ -86,7 +88,8 @@ describe "when using sudo", :sudo => true do
end
it "installs extensions/ compiled by Rubygems 2.2", :rubygems => "2.2" do
- install_gemfile <<-G, :system => true
+ bundler "config path.system true"
+ install_gemfile <<-G
source "file://#{gem_repo1}"
gem "very_simple_binary"
G
@@ -139,7 +142,8 @@ describe "when using sudo", :sudo => true do
gem "rack", '1.0'
G
- bundle :install, :env => { "GEM_HOME" => gem_home.to_s, "GEM_PATH" => nil }, :system => true
+ bundler "config path.system true"
+ bundle :install, :env => { "GEM_HOME" => gem_home.to_s, "GEM_PATH" => nil }
expect(gem_home.join("bin/rackup")).to exist
should_be_installed "rack 1.0", :env => { "GEM_HOME" => gem_home.to_s, "GEM_PATH" => nil }
end
diff --git a/spec/other/platform_spec.rb b/spec/other/platform_spec.rb
index 9e389dd647..eeb8f786c2 100644
--- a/spec/other/platform_spec.rb
+++ b/spec/other/platform_spec.rb
@@ -540,7 +540,9 @@ G
context "bundle show" do
before do
- install_gemfile <<-G, :system => true
+ bundle "config path.system true"
+
+ install_gemfile <<-G
source "file://#{gem_repo1}"
gem "rails"
G
@@ -874,7 +876,9 @@ G
context "bundle console" do
before do
- install_gemfile <<-G, :system => true
+ bundle "config path.system true"
+
+ install_gemfile <<-G
source "file://#{gem_repo1}"
gem "rack"
gem "activesupport", :group => :test
diff --git a/spec/commands/exec_spec.rb b/spec/commands/exec_spec.rb
index 58bf40e679..7ab4b6ce7f 100644
--- a/spec/commands/exec_spec.rb
+++ b/spec/commands/exec_spec.rb
@@ -114,16 +114,18 @@ describe "bundle exec" do
end
end
# We added :system => true here and in the block below, since the
# (old default) system gem directory was implicitly used in previous
# versions of Bundler.
- install_gemfile <<-G, :system => true
+ bundle "config path.system true"
+
+ install_gemfile <<-G
source "file://#{gem_repo1}"
gem "rack", "0.9.1"
G
Dir.chdir bundled_app2 do
- install_gemfile bundled_app2("gems.rb"), <<-G, :system => true
+ install_gemfile bundled_app2("gems.rb"), <<-G
source "file://#{gem_repo2}"
gem "rack_two", "1.0.0"
G
@@ -114,16 +114,18 @@ describe "bundle exec" do
end
end
- # We added :system => true here and in the block below, since the
+ # We added `config path.system true` here, since the
# (old default) system gem directory was implicitly used in previous
# versions of Bundler.